@@ -8,7 +8,7 @@ export interface MDXWrapperProps {
 /**
  * A wrapper component for MDX content that adds a title if one is provided in the frontmatter.
  */
-export const MDXWrapper: React.FC<MDXWrapperProps> = ({ children, frontmatter }) => {
+export const MDXWrapper = ({ children, frontmatter }: MDXWrapperProps) => {
     const { title } = frontmatter;
     const nextChildren = React.Children.toArray(children);
 
@@ -16,5 +16,5 @@ export const MDXWrapper: React.FC<MDXWrapperProps> = ({ children, frontmatter })
         nextChildren.unshift(<h1 key="header-title">{title}</h1>);
     }
 
-    return <>{nextChildren}</>;
+    return <div className="pf-c-content">{nextChildren}</div>;
 };
