@@ -22,13 +22,6 @@ export function randomId() {
     return "xxxxxxxx".replace(/x/g, (c) => {
         const r = (dt + Math.random() * 16) % 16 | 0;
         dt = Math.floor(dt / 16);
-        return (c == "x" ? r : (r & 0x3) | 0x8).toString(16);
+        return (c === "x" ? r : (r & 0x3) | 0x8).toString(16);
     });
 }
-
-export function convertToSlug(text: string) {
-    return text
-        .toLowerCase()
-        .replace(/ /g, "-")
-        .replace(/[^\w-]+/g, "");
-}
